@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::Role::Command;
-$BalanceOfPower::Commands::Role::Command::VERSION = '0.110000';
+$BalanceOfPower::Commands::Role::Command::VERSION = '0.115000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -16,6 +16,15 @@ has synonyms => (
     is => 'rw',
     default => sub { [] }
 );
+has export_cost => (
+    is => 'ro',
+    default => 0
+);
+has domestic_cost => (
+    is => 'ro',
+    default => 0
+);
+
 has allowed_at_war => (
     is => 'ro',
     default => 0
@@ -44,19 +53,27 @@ sub allowed
     }
     if(exists $self->production_limit->{'<'})
     {
-        return $self->world->get_player_nation()->production() < $self->production_limit->{'<'};
+        return $self->world->get_player_nation()->production() <= $self->production_limit->{'<'};
     }
     elsif(exists $self->production_limit->{'>'})
     {
-        return $self->world->get_player_nation()->production() > $self->production_limit->{'>'};
+        return $self->world->get_player_nation()->production() >= $self->production_limit->{'>'};
     }
     if(exists $self->army_limit->{'<'})
     {
-        return $self->world->get_player_nation()->army() < $self->army_limit->{'<'};
+        return $self->world->get_player_nation()->army() <= $self->army_limit->{'<'};
     }
     elsif(exists $self->army_limit->{'>'})
     {
-        return $self->world->get_player_nation()->army() > $self->army_limit->{'>'};
+        return $self->world->get_player_nation()->army() >= $self->army_limit->{'>'};
+    }
+    if($self->world->get_player_nation()->production_for_domestic < $self->domestic_cost)
+    {
+        return 0;
+    }
+    if($self->world->get_player_nation()->production_for_export < $self->export_cost)
+    {
+        return 0;
     }
     return 1;
 }
