@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.110000';
+$BalanceOfPower::Nation::VERSION = '0.115000';
 use strict;
 use v5.10;
 
@@ -49,6 +49,10 @@ has production_for_export => (
     is => 'rw',
     default => 0
 );
+has prestige => (
+    is => 'rw',
+    default => 0
+);
 has wealth => (
     is => 'rw',
     default => 0
@@ -245,23 +249,30 @@ sub military_advisor
             {
                 my $enemy = $world->get_nation($c->destination($self->name));
                 next if $world->war_busy($enemy->name);
-                if($self->good_prey($enemy, $world, $c->crisis_level))
+                if($world->in_military_range($self->name, $enemy->name))
                 {
-                    if($world->in_military_range($self->name, $enemy->name))
+                    if($self->good_prey($enemy, $world, $c->crisis_level))
                     {
                         return $self->name . ": DECLARE WAR TO " . $enemy->name;
                     }
                     else
                     {
-                        if($self->army >= MIN_ARMY_TO_EXPORT)
+                        if($self->production_for_export >= AID_INSURGENTS_COST)
                         {
-                            my @friends = $world->get_friends($self->name);                        
-                            for(@friends)
+                            return $self->name . ": AID INSURGENTS IN " . $enemy->name;
+                        }
+                    }
+                }
+                else
+                {
+                    if($self->army >= MIN_ARMY_TO_EXPORT)
+                    {
+                        my @friends = $world->get_friends($self->name);                        
+                        for(@friends)
+                        {
+                            if($world->border_exists($_, $enemy->name))
                             {
-                                if($world->border_exists($_, $enemy->name))
-                                {
-                                    return $self->name . ": MILITARY SUPPORT " . $_;
-                                }
+                                return $self->name . ": MILITARY SUPPORT " . $_;
                             }
                         }
                     }
@@ -383,7 +394,7 @@ sub good_prey
 
                     
     #COALITION EVALUATION
-    if($world->coalition($self->name) && $world->coalition($enemy->name) && $world->coalition($self->name) > $world->coalition($enemy->name))
+    if($world->empire($self->name) && $world->empire($enemy->name) && $world->empire($self->name) > $world->empire($enemy->name))
     {
         $war_points += 1;
     }
@@ -630,11 +641,8 @@ sub occupation
 sub build_troops
 {
     my $self = shift;
-    my $army_cost = ARMY_COST;
-    if($self->government eq 'dictatorship')
-    {
-        $army_cost -= DICTATORSHIP_BONUS_FOR_ARMY_CONSTRUCTION;
-    }
+    my $army_cost = $self->build_troops_cost();
+  
     if($self->production_for_export > $army_cost && $self->army < MAX_ARMY_FOR_SIZE->[ $self->size ])
     {
         $self->subtract_production('export', $army_cost);
@@ -642,6 +650,17 @@ sub build_troops
         $self->register_event("NEW TROOPS FOR THE ARMY");
     } 
 }
+sub build_troops_cost
+{
+    my $self = shift;
+    my $army_cost = ARMY_COST;
+    if($self->government eq 'dictatorship')
+    {
+        $army_cost -= DICTATORSHIP_BONUS_FOR_ARMY_CONSTRUCTION;
+    }
+    return $army_cost;
+}
+
 sub add_army
 {
     my $self = shift;
