@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::Friendship;
-$BalanceOfPower::Relations::Friendship::VERSION = '0.110000';
+$BalanceOfPower::Relations::Friendship::VERSION = '0.115000';
 use strict;
 use v5.10;
 
@@ -156,7 +156,7 @@ sub is_crisis
 sub is_max_crisis
 {
     my $self = shift;
-    return $self->crisis_level = CRISIS_MAX_FACTOR;
+    return $self->crisis_level(CRISIS_MAX_FACTOR);
 }
 
 
