@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Diplomat;
-$BalanceOfPower::Role::Diplomat::VERSION = '0.110000';
+$BalanceOfPower::Role::Diplomat::VERSION = '0.115000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -219,7 +219,7 @@ sub print_diplomacy
     }
     return $out;
 }
-sub coalition
+sub empire
 {
     my $self = shift;
     my $n = shift;
@@ -237,21 +237,7 @@ sub coalition
         return @allies;
     }
 }
-sub in_military_range
-{
-    my $self = shift;
-    my $nation1 = shift;
-    my $nation2 = shift;
-    return 1 if($self->border_exists($nation1, $nation2));
-    my @supported = $self->supporter($nation1);
-    for(@supported)
-    {
-        my $nation_supported = $_->destination($nation1);
-        return 1 if $nation_supported eq $nation2 ||
-                    $self->border_exists($nation_supported, $nation2);
-    }
-    return 0;
-}
+
 
 #Functions to manage relationships as crises
 sub add_crisis
