@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Historian;
-$BalanceOfPower::Role::Historian::VERSION = '0.110000';
+$BalanceOfPower::Role::Historian::VERSION = '0.115000';
 use strict;
 use Moo::Role;
 use Term::ANSIColor;
@@ -75,11 +75,11 @@ sub print_nation_statistics_header
 {
     if(DEBT_ALLOWED)
     {
-        return "Size\tProd.\tWealth\tW/D\tGrowth\tDelta\tDebt\tDisor.\tArmy";
+        return "Size\tProd.\tWealth\tW/D\tGrowth\tDelta\tDebt\tDisor.\tArmy"; #\tPstg.";
     }
     else
     {
-        return "Size\tProd.\tWealth\tW/D\tGrowth\tDelta\tDisor.\tArmy";
+        return "Size\tProd.\tWealth\tW/D\tGrowth\tDelta\tDisor.\tArmy"; #\tPstg.";
     }
 }
 sub print_nation_statistics_line
@@ -114,6 +114,7 @@ sub print_nation_statistics_line
     }
     $out .= $self->get_statistics_value($y, $nation, 'internal disorder') . "\t";
     $out .= $self->get_statistics_value($y, $nation, 'army') . "\t";
+    #$out .= $self->get_statistics_value($y, $nation, 'prestige') . "\t";
     return $out;
 }
 
@@ -196,6 +197,23 @@ sub medium_statistics
     return ($medium_production, $medium_wealth, $medium_disorder);
 }
 
+sub order_statistics
+{
+    my $self = shift;
+    my $turn = shift;
+    my $value = shift;
+    my @nations = @{$self->nation_names};
+    my @ordered;
+    foreach my $n (@nations)
+    {
+        my $val = $self->get_statistics_value($turn, $n, $value);
+        return () if(! $val);
+        push @ordered, { nation => $n, value => $val }; 
+    }
+    @ordered = sort { $a->{value} <=> $b->{value} } @ordered;
+    return @ordered;
+}
+
 sub print_crises
 {
     my $self = shift;
