@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.110000';
+$BalanceOfPower::World::VERSION = '0.115000';
 use strict;
 use v5.10;
 
@@ -280,8 +280,11 @@ sub init_year
         $n->wealth(0);
         my $prod = $self->calculate_production($n);
         $n->production($prod);
+        my $prestige = $self->calculate_prestige($n);
+        $n->prestige($prestige);
         $self->set_statistics_value($n, 'production', $prod);
         $self->set_statistics_value($n, 'debt', $n->debt);
+        $self->set_statistics_value($n, 'prestige', $prestige);
     }
 }
 
@@ -384,6 +387,44 @@ sub loot
 
 # PRODUCTION MANAGEMENT END ###############################################
 
+# PRESTIGE MANAGEMENT #####################################################
+
+sub calculate_prestige
+{
+    my $self = shift;
+    my $nation = shift;
+    my $nation_name = $nation->name;
+    my $prestige = 0;
+    my @routes = $self->routes_for_node($nation_name);
+    $prestige += @routes;
+    my @supported = $self->supporter($nation_name);
+    $prestige += @supported;
+    my @influenced = $self->has_influence($nation_name);
+    $prestige += @influenced * INFLUENCE_PRESTIGE_BONUS;
+    my @ordered_wealth = $self->order_statistics(prev_turn($nation->current_year), 'wealth');
+    my $bonus = 0;
+    if(@ordered_wealth >= BEST_WEALTH_FOR_PRESTIGE)
+    {
+        for(my $i = 0; $i < BEST_WEALTH_FOR_PRESTIGE; $i++)
+        {
+            if($ordered_wealth[$i]->{nation} eq $nation_name)
+            {
+                $bonus = BEST_WEALTH_FOR_PRESTIGE_BONUS;
+                $self->broadcast_event("ONE OF THE FIRST " . BEST_WEALTH_FOR_PRESTIGE . " NATIONS FOR WEALTH WAS " . $nation_name, $nation_name);
+            }
+        }
+    }
+    $prestige += $bonus;
+    my @wins = $nation->get_events("WAR BETWEEN .* AND .* WON BY ". $nation_name, prev_turn($nation->current_year));
+    if(@wins > 0)
+    {
+        $prestige += WAR_PRESTIGE_BONUS;
+    }
+    return $prestige;
+}
+
+# PRESTIGE MANAGEMENT END #####################################################
+
 # DECISIONS ###############################################################
 
 # Decisions are collected and executed
@@ -445,6 +486,12 @@ sub execute_decisions
            my $supported = $self->get_nation($2);
            $self->stop_military_support($supporter, $supported);
         }
+        elsif($d =~ /^(.*): AID INSURGENTS IN (.*)$/)
+        {
+            my $attacker = $self->get_nation($1);
+            my $victim = $self->get_nation($2);
+            $self->aid_insurgents($attacker, $victim);
+        }
     }
     $self->manage_route_adding(@route_adders);
 }
@@ -574,6 +621,19 @@ sub internal_conflict
     }
 }
 
+sub aid_insurgents
+{
+    my $self = shift;
+    my $nation1 = shift;
+    my $nation2 = shift;
+    if($nation1->production_for_export > AID_INSURGENTS_COST && $nation2->internal_disorder_status ne 'Civil war')
+    {
+        $self->broadcast_event("AIDS FOR INSURGENTS OF " . $nation2->name . " FROM " . $nation1->name, $nation1->name, $nation2->name);
+        $nation1->subtract_production('export', AID_INSURGENTS_COST);
+        $nation2->add_internal_disorder(INSURGENTS_AID);
+    }
+}
+
 # INTERNAL DISORDER END ######################################################
 
 # WAR ######################################################################
